Fix: Fix parameters for a tool wrapper

Description Usage Arguments

View source: R/01_BenchmarkSetUp_00_Modules.R

Description

Takes a projection or clustering tool wrapper and fixes given parameter values for it.

Usage

1
Fix(tool_name, ...)

Arguments

tool_name

name of a tool for which a wrapper (generated by WrapTool) exists in the global namespace

...

named parameter values to fix for training a model using wrapper


davnovak/SingleBench documentation built on Dec. 19, 2021, 9:10 p.m.