GetClusteringScores: Get 'Benchmark' clustering evaluation scores

Description Usage Arguments See Also

View source: R/99_Getters.R

Description

Extracts list of evaluation scores and other products of evaluating performance of a clustering tool used in a subpipeline n-iteration in a Benchmark object (benchmark pipeline set-up).

Usage

1
GetClusteringScores(benchmark, idx.subpipeline, idcs.n_param = NULL)

Arguments

benchmark

object of type Benchmark

idx.subpipeline

integer: index of a subpipeline of benchmark

idx.n_param

integer: index of an n-parameter iteration of a sub-pipeline of benchmark

See Also


davnovak/SingleBench documentation built on Dec. 19, 2021, 9:10 p.m.