PlotClustersOverlay: Create a clusters-overlay plot

Description Usage Arguments Details See Also

View source: R/04_Visual_Overlays.R

Description

Creates a plot showing separation of generated clusters using previously generated 2-dimensional layout of input expression data. For large numbers of data points, this function uses raster graphics to visualise the layout faster.

Usage

1
2
3
4
5
6
7
8
PlotClustersOverlay(
  benchmark,
  idx.subpipeline,
  idcs.n_param = NULL,
  exclude_unassigned = FALSE,
  raster_threshold = 5000L,
  plot_title = "Clustering"
)

Arguments

benchmark

object of type Benchmark

idx.subpipeline

integer: index of sub-pipeline that includes a clustering step

idcs.n_param

integer or vector of integers: indices of n-parameter (cluster count) of interest. Default value is NULL, which translates to all n-parameter iterations of the given sub-pipeline

exclude_unassigned

logical: if TRUE, data points that are considered unassigned per manual annotation are omitted. Default value is FALSE

raster_threshold

integer: maximum number of data points for which vector graphics should be used. Default value is 5000

plot_title

string: title of the plot. Default value is 'Clustering'

Details

You need to specify a single sub-pipeline and one or more n-parameter iteration by index. If multiple n-parameter iterations are chosen, a list of plots will be generated.

You can choose a custom title for your plot. The plot subtitle is always the n-parameter iteration name.

See Also


davnovak/SingleBench documentation built on Dec. 19, 2021, 9:10 p.m.