PlotRMSDToSize: Plot RMSD-to-size plots for clustering result

Description Usage Arguments Details

View source: R/04_Visual_RMSDToSize.R

Description

Plots a grid of RMSD-to-size plots per manually assigned population. This is an experimental tool to assess dissimilarities between manual labelling of data and the result of automated clustering.

Usage

1
PlotRMSDToSize(benchmark, idx.subpipeline, idx.n_param = NULL, idx.run = 1)

Arguments

benchmark

an object of class Benchmark, as generated by the constructor Benchmark and evaluated using Evaluate.Benchmark

idx.subpipeline

integer value: index of sub-pipeline that includes a projection step

idx.n_param

integer value: index of n-parameter iteration if n-parameters were used. Deault value is NULL

idx.run

integer value: number of run to select if multiple (repeated) runs of clustering algorithm are available. Default value is 1

Details

RMSD (root mean square deviation) is a measure of the average variation in signal across all parameters. A high RMSD will be seen in groups of points that span a large part of the high-dimensional space or are irregular in shape. In the plotted grid, vertical axis shows RMSD and horizontal axis shows size.

The RMSD-to-size ratio is computed for each manually labelled population, each cluster mapped to it (by the fixed-cluster scheme) and the union of all the clusters matched to it. Properties of clusters can be investigated based on their position in the grid relative to the matched (reference) population. We assume that

Then for example, if a population mostly has clusters in the bottom-left quadrant matched to it, it seems the clustering identified smaller constituent populations that go beyond the resolution of manual labelling. If a gating strategy has many unlabelled cells and we see clusters that are to the right of the reference population on the grid, these might likely correspond to unlabelled cells that really belong to the reference.


davnovak/SingleBench documentation built on Dec. 19, 2021, 9:10 p.m.