View source: R/01_BenchmarkSetUp_00_Modules.R
Takes a projection or clustering tool wrapper and fixes given parameter values for it.
1 |
tool_name |
name of a tool for which a wrapper (generated by |
... |
named parameter values to fix for training a model using |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.