Description Usage Arguments Details See Also
View source: R/04_Visual_Overlays.R
Creates a plot showing separation of generated clusters using previously generated 2-dimensional layout of input expression data. For large numbers of data points, this function uses raster graphics to visualise the layout faster.
1 2 3 4 5 6 7 8 | PlotClustersOverlay(
benchmark,
idx.subpipeline,
idcs.n_param = NULL,
exclude_unassigned = FALSE,
raster_threshold = 5000L,
plot_title = "Clustering"
)
|
benchmark |
object of type |
idx.subpipeline |
integer: index of sub-pipeline that includes a clustering step |
idcs.n_param |
integer or vector of integers: indices of n-parameter (cluster count) of interest. Default value is |
exclude_unassigned |
logical: if |
raster_threshold |
integer: maximum number of data points for which vector graphics should be used. Default value is |
plot_title |
string: title of the plot. Default value is 'Clustering' |
You need to specify a single sub-pipeline and one or more n-parameter iteration by index. If multiple n-parameter iterations are chosen, a list of plots will be generated.
You can choose a custom title for your plot. The plot subtitle is always the n-parameter iteration name.
Benchmark: constructs a Benchmark object (benchmark pipeline set-up)\
Evaluate: runs all benchmark sub-pipelines and scores the performance of each tool
AddLayout: allows you to add a separate 2-dimensional layout of the input dataset or to use an existing projection (produced in the evaluation) as a visualisation layout.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.